defmodule Frenzy.Group do
  use Ecto.Schema
  import Ecto.Changeset

  def to_fever_group(group) do
    %{
      id: group.id,
      title: group.title
    }
  end

  def to_fever_feeds_group(group) do
    %{
      group_id: group.id,
      feed_ids: group.feeds |> Enum.map(fn feed -> feed.id end) |> Enum.join(",")
    }
  end

  schema "groups" do
    field :title, :string

    belongs_to :user, Frenzy.User

    has_many :feeds, Frenzy.Feed, on_delete: :delete_all

    timestamps()
  end

  @doc false
  def changeset(group, attrs) do
    group
    |> cast(attrs, [:title])
    |> validate_required([:title])
  end
end
